summaryrefslogtreecommitdiff
path: root/sbin/dump/dump.h
diff options
context:
space:
mode:
Diffstat (limited to 'sbin/dump/dump.h')
-rw-r--r--sbin/dump/dump.h76
1 files changed, 38 insertions, 38 deletions
diff --git a/sbin/dump/dump.h b/sbin/dump/dump.h
index 83023c68773..f2f8cb4528f 100644
--- a/sbin/dump/dump.h
+++ b/sbin/dump/dump.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: dump.h,v 1.24 2015/05/23 05:17:20 guenther Exp $ */
+/* $OpenBSD: dump.h,v 1.25 2021/01/21 00:16:36 mortimer Exp $ */
/* $NetBSD: dump.h,v 1.11 1997/06/05 11:13:20 lukem Exp $ */
/*-
@@ -35,10 +35,10 @@
/*
* Dump maps used to describe what is to be dumped.
*/
-int mapsize; /* size of the state maps */
-char *usedinomap; /* map of allocated inodes */
-char *dumpdirmap; /* map of directories to be dumped */
-char *dumpinomap; /* map of files to be dumped */
+extern int mapsize; /* size of the state maps */
+extern char *usedinomap; /* map of allocated inodes */
+extern char *dumpdirmap; /* map of directories to be dumped */
+extern char *dumpinomap; /* map of files to be dumped */
/*
* Map manipulation macros.
*/
@@ -52,35 +52,35 @@ char *dumpinomap; /* map of files to be dumped */
/*
* All calculations done in 0.1" units!
*/
-char *disk; /* name of the disk file */
-char *tape; /* name of the tape file */
-char *dumpdates; /* name of the file containing dump date information*/
-char *temp; /* name of the file for doing rewrite of dumpdates */
-char *duid; /* duid of the disk being dumped */
-char lastlevel; /* dump level of previous dump */
-char level; /* dump level of this dump */
-int uflag; /* update flag */
-int diskfd; /* disk file descriptor */
-int tapefd; /* tape file descriptor */
-int pipeout; /* true => output to standard output */
-ino_t curino; /* current inumber; used globally */
-int newtape; /* new tape flag */
-int density; /* density in 0.1" units */
-int64_t tapesize; /* estimated tape size, blocks */
-int64_t tsize; /* tape size in 0.1" units */
-int unlimited; /* if set, write to end of medium */
-int64_t asize; /* number of 0.1" units written on current tape */
-int etapes; /* estimated number of tapes */
-int nonodump; /* if set, do not honor UF_NODUMP user flags */
-
-int notify; /* notify operator flag */
-int64_t blockswritten; /* number of blocks written on current tape */
-int tapeno; /* current tape number */
-time_t tstart_writing; /* when started writing the first tape block */
-long xferrate; /* averaged transfer rate of all volumes */
-struct fs *sblock; /* the file system super block */
-char sblock_buf[MAXBSIZE];
-int tp_bshift; /* log2(TP_BSIZE) */
+extern char *disk; /* name of the disk file */
+extern char *tape; /* name of the tape file */
+extern char *dumpdates; /* name of the file containing dump date information*/
+extern char *duid; /* duid of the disk being dumped */
+extern char lastlevel; /* dump level of previous dump */
+extern char level; /* dump level of this dump */
+extern int uflag; /* update flag */
+extern int diskfd; /* disk file descriptor */
+extern int pipeout; /* true => output to standard output */
+extern ino_t curino; /* current inumber; used globally */
+extern int newtape; /* new tape flag */
+extern int density; /* density in 0.1" units */
+extern int64_t tapesize; /* estimated tape size, blocks */
+extern int64_t tsize; /* tape size in 0.1" units */
+extern int unlimited; /* if set, write to end of medium */
+extern int etapes; /* estimated number of tapes */
+extern int nonodump; /* if set, do not honor UF_NODUMP user flags */
+extern int notify; /* notify operator flag */
+extern int64_t blockswritten; /* number of blocks written on current tape */
+extern int tapeno; /* current tape number */
+extern int ntrec; /* blocking factor on tape */
+extern int64_t blocksperfile; /* number of blocks per output file */
+extern int cartridge; /* assume non-cartridge tape */
+extern char *host; /* remote host (if any) */
+extern time_t tstart_writing; /* when started writing the first tape block */
+extern long xferrate; /* averaged transfer rate of all volumes */
+extern struct fs *sblock; /* the file system super block */
+extern char sblock_buf[MAXBSIZE];
+extern int tp_bshift; /* log2(TP_BSIZE) */
/* operator interface functions */
void broadcast(char *message);
@@ -163,10 +163,10 @@ struct dumptime {
struct dumpdates dt_value;
struct dumptime *dt_next;
};
-struct dumptime *dthead; /* head of the list version */
-int nddates; /* number of records (might be zero) */
-int ddates_in; /* we have read the increment file */
-struct dumpdates **ddatev; /* the arrayfied version */
+extern struct dumptime *dthead; /* head of the list version */
+extern int ddates_in; /* we have read the increment file */
+extern int nddates; /* number of records (might be zero) */
+extern struct dumpdates **ddatev; /* the arrayfied version */
void initdumptimes(void);
void getdumptime(void);
void putdumptime(void);